<?php
// wbb imports
require_once(WBB_DIR.'lib/data/post/ViewablePost.class.php');
require_once(WBB_DIR.'lib/data/thread/ViewableThread.class.php');
require_once(WBB_DIR.'lib/data/boxes/PortalBox.class.php');
require_once(WBB_DIR.'lib/data/boxes/StandardPortalBox.class.php');
require_once(WBB_DIR.'lib/data/thread/ThreadList.class.php');

/**
 * A compact box which displays the latest news and threads#
 * It uses the data which is gathered by the news and last threads
 * box to save performance
 *
 * @package		com.woltlab.community.portal.compactNews
 * @author		WoltLab Community
 * @copyright	2009 WoltLab Community
 * @license		GNU Lesser Public License <http://www.gnu.org/licenses/lgpl.html>
 * @subpackage	data.boxes
 * @category	Portal
 */
class CompactNewsBox extends PortalBox implements StandardPortalBox {
	public $stylesheet = 'compactnews';

	/**
	 * @see StandardPortalBox::readData()
	 */
	public function readData() {
		$this->cacheData = array();

		$boardIDs = Board::getAccessibleBoardIDArray();
		$skipBoardIDs = '0';

		// No boards are visible to viewer, no action required
		if (empty($boardIDs)) return;

		// determine if any more boards are hidden by configuration
		if (LASTTHREADSBOX_SKIP_BOARDIDS != '') {
			$skipBoardIDs = LASTTHREADSBOX_SKIP_BOARDIDS;
			$boardIDs = array_diff($boardIDs, explode(',', $skipBoardIDs));
			if (empty($boardIDs)) return;
		}

		$threadList = new ThreadList();
		$threadList->limit = COMPACTNEWS_THREAD_ITEMS;
		$threadList->sqlConditions = 'boardID IN('.implode(',', $boardIDs).')
						AND thread.isDeleted = 0
						AND thread.isDisabled = 0
						AND thread.movedThreadID = 0';
		$threadList->sqlSelects = 'thread_visit.lastVisitTime,';
		$threadList->sqlJoins = "	LEFT JOIN 	wbb".WBB_N."_thread_visit thread_visit
						ON 		(thread_visit.threadID = thread.threadID
								AND thread_visit.userID = ".WCF::getUser()->userID.")";
		// sort resulsts by posttime
		if (LASTTHREADSBOX_SORT == 'posttime') {
			$threadList->sqlOrderBy	= "thread.lastPostTime DESC, thread.time DESC";
		}
		else {
			$threadList->sqlOrderBy	= "thread.time DESC";
		}


		$threadList->readThreads();


		foreach ($threadList->threads as $key => $thread) {
			$thread->title = WCF::getLanguage()->get($thread->title);
			$tmp = StringUtil::length($thread->topic);

			// truncate topic if necessary
			if (COMPACTNEWSBOX_THREADCUT_ACTIVE && ($tmp > COMPACTNEWSBOX_THREADCUT_ITEMS)) {
				$tmp = ($thread->prefix) ? (COMPACTNEWSBOX_THREADCUT_ITEMS - StringUtil::length($thread->prefix) -1) : COMPACTNEWSBOX_THREADCUT_ITEMS;
				if ($tmp < 1) $tmp = 1;
				$thread->topic	= StringUtil::substring($thread->topic, 0, $tmp) . " [...]";
			}
			$this->cacheData['threads'][] = $thread;
		}

		//reset threadList
		$threadList->threads = array();
		
		//get news cache
		$newsBox = PortalBox::getBoxByName('news');
		if (!count($newsBox->cacheData)) {
			$newsBox->initialize();
		}
		
		$newsBoxData = array();
		//truncate subject if necessary
		if (COMPACTNEWSBOX_THREADCUT_ACTIVE) {
			foreach ($newsBox->cacheData as $newsData) {
				$titleLenght = StringUtil::length($newsData['subject']);
				$tmp = ($newsData['prefix']) ? (COMPACTNEWSBOX_THREADCUT_ITEMS - StringUtil::length($newsData['prefix']) - 1) : COMPACTNEWSBOX_THREADCUT_ITEMS;
				if ($tmp < 1) $tmp = 1;
				$newsData['subject'] = ($titleLenght > $tmp) ? StringUtil::substring($newsData['subject'], 0, $tmp) . " [...]" : $newsData['subject'];
				$newsBoxData[] = $newsData;
			}
		} else {
			$newsBoxData = $newsBox->cacheData;	
		}
		
		$this->cacheData['news'] = array_slice($newsBoxData, 0, COMPACTNEWS_NEWS_ITEMS);
		
	}

	/**
	 * @see StandardPortalBox::getTemplateName()
	 */
	public function getTemplateName() {
		return 'compactNewsBox';
	}
}
?>